==> mangadex_library-1.2.8%2B2.tar.gz: lib/models/cover/Cover.dart <==
import 'package:mangadex_library/models/common/relationships.dart';

class Cover {
  late List<Data> data;
  late int limit;
  late int offset;
  late int total;
  Cover(this.data, this.limit, this.offset, this.total);
  Cover.fromJson(Map<String, dynamic> json) {
    if (json['results'] != null) {
      data = <Data>[];
      json['results'].forEach((v) {
        data.add(Data.fromJson(v));
      });
    }
    limit = json['limit'] ?? 0;
    offset = json['offset'] ?? 0;
    total = json['total'] ?? 0;
  }
}

class Data {
  late String id;
  late String type;
  late List<Relationship> relationships;
  late Attributes attributes;
  Data(this.id, this.type, this.attributes, this.relationships);
  Data.fromJson(Map<String, dynamic> json) {
    id = json['id'] ?? '';
    type = json['type'] ?? '';
    if (json['attributes'] != null) {
      attributes = Attributes.fromJson(json['attributes']);
    }
  }
}

class Attributes {
  late String volume;
  late String fileName;
  late String description;
  late int version;
  late String createdAt;
  late String updatedAt;
  Attributes(this.volume, this.fileName, this.description, this.version,
      this.createdAt, this.updatedAt);
  Attributes.fromJson(Map<String, dynamic> json) {
    volume = json['volume'] ?? 'null';
    fileName = json['fileName'] ?? 'null';
    description = json['description'] ?? 'null';
    version = json['version'] ?? 'null';
    createdAt = json['createdAt'] ?? 'null';
    updatedAt = json['updatedAt'] ?? 'null';
  }
}

==> mangadex_library-1.2.9%2B2.tar.gz: lib/models/cover/Cover.dart <==
import 'package:mangadex_library/models/common/relationships.dart';

class Cover {
  late List<Data> data;
  late int limit;
  late int offset;
  late int total;
  Cover(this.data, this.limit, this.offset, this.total);
  Cover.fromJson(Map<String, dynamic> json) {
    data = <Data>[];
    json['data']!.forEach((v) {
      data.add(Data.fromJson(v));
    });

    limit = json['limit'] ?? 0;
    offset = json['offset'] ?? 0;
    total = json['total'] ?? 0;
  }
}

class Data {
  late String id;
  late String type;
  late List<Relationship> relationships;
  late Attributes attributes;
  Data(this.id, this.type, this.attributes, this.relationships);
  Data.fromJson(Map<String, dynamic> json) {
    id = json['id'] ?? '';
    type = json['type'] ?? '';
    json['relationships'].forEach((v) {
      relationships.add(Relationship.fromJson(v));
    });
    attributes = Attributes.fromJson(json['attributes']!);
  }
}

class Attributes {
  late String volume;
  late String fileName;
  late String description;
  late int version;
  late String createdAt;
  late String updatedAt;
  Attributes(this.volume, this.fileName, this.description, this.version,
      this.createdAt, this.updatedAt);
  Attributes.fromJson(Map<String, dynamic> json) {
    volume = json['volume'] ?? 'null';
    fileName = json['fileName'] ?? 'null';
    description = json['description'] ?? 'null';
    version = json['version'] ?? 'null';
    createdAt = json['createdAt'] ?? 'null';
    updatedAt = json['updatedAt'] ?? 'null';
  }
}
